@@ -115,7 +115,7 @@ class GCloudStorageClient():
         splitted_name = list(filter(None, splitted_name))
         blob.download_to_filename(output_folder + '/' + splitted_name[len(splitted_name) - 1])
 
-    def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False):
+    def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, validate=False):
         bucket = self.client.get_bucket(self.bucket_name)
         if dst_folder[0] == '/':
             dst_folder = dst_folder[1:len(dst_folder)]
